<?php
/**
 * @file
* Contains \Drupal\vuetable\Element\VuetableElement.
*/

namespace Drupal\vuetable\Element;

use Drupal\Core\Render\Element\RenderElement;
use Drupal\Core\Url;

/**
 * Provides an vuetable element.
 *
 * @RenderElement("vuetable_element")
 */
class VuetableElement extends RenderElement {
  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $class = get_class($this);
    return [
        '#theme' => 'vuetable_element',
        '#label' => 'Default Label',
        '#description' => 'Default Description',
        '#pre_render' => [
            [$class, 'preRenderVuetableElement'],
        ],
        '#attached' => [
            'library' => ['vuetable/vue-js', 'vuetable/vue-table', 'vuetable/vuetable-element-js',],
        ],
    ];
  }

  /**
   * Prepare the render array for the template.
   */
  public static function preRenderVuetableElement($element) {
    //Pass fields to js as a setting variable
    $element['#attached']['drupalSettings']['fields'] =  $element['#fields'];
    //The api URL is where the table fetch data from
    $element['#attached']['drupalSettings']['url'] = $element['#api_url'];
    //By default the sort parameter for Vuetable looks lik this 'sort=name|asc'
    //But for a REST API generated by Views in Drupal, the sort order parameter is 'sort_order'
    //So we need to pass the parameter name to JavaScript if it needs to change
    if (isset($element['#order_param'])) {
      $element['#attached']['drupalSettings']['sort_order_param'] = $element['#order_param'];
    }
    //The page number for a Drupal view start from 0, but by default, a vuetalbe page starts from 1
    //So for any API that page starts from 0, we have to pass the informtion to the JavaScript code
    //Also we have to change the page number parameter name if the pagination rule is changed
    if (isset($element['#start_page'])) {
      $element['#attached']['drupalSettings']['page_start_from'] = $element['#start_page'];
      $element['#attached']['drupalSettings']['page_param'] = $element['#page'];
      $element['#page'] = 'client_' + $element['#page'];
    }
    
    return $element;
  }
}